@@ -20,7 +20,7 @@ pub fn exec() -> Result<()> {
     }: ResourceConfig = resource.clone();
     if let Some(ref version) = version {
         eprintln!(
-            "Last deployed trigger: '{}', checking if we can deploy a newer version",
+            "Last trigger: '{}', checking if we can deploy a newer version",
             version.trigger
         );
     } else {
@@ -56,21 +56,21 @@ pub fn exec() -> Result<()> {
         repo.pull(conf)?;
         repo
     };
+    let (hash, summary) = repo.head_commit_summary()?;
     eprintln!(
-        "HEAD of branch '{}' is now at: '{}'",
-        source.branch,
-        repo.head_commit_hash()?
+        "HEAD of branch '{}' is now at: [{}] - {}",
+        source.branch, hash, summary
     );
 
     let config = Config::from_file(&source.config)?;
-    let ws = Workspace::new(&config.scope, source.config)?;
+    let ws = Workspace::new(&config.scope, source.config.clone(), source.ignore_queue)?;
     let environment = source
         .environment
         .ok_or_else(|| anyhow!("Environment not specified in source"))?;
-    let env = config
-        .environments
-        .get(&environment)
-        .context(format!("Environment '{}' not found in config", environment))?;
+    let env = config.environments.get(&environment).context(format!(
+        "Environment '{}' not found in config '{}'",
+        environment, source.config
+    ))?;
     eprintln!("Checking equivalence with last deployed state...");
     let mut res = Vec::new();
     let gate = get_gate(
@@ -89,8 +89,13 @@ pub fn exec() -> Result<()> {
             res.push(last);
             res.push(Version { trigger })
         }
-        (Some(last), _) => {
-            eprintln!("Nothing new to deploy");
+        (Some(last), ret) => {
+            match ret {
+                Some((trigger, _)) if last.trigger == trigger => {
+                    eprintln!("Last trigger is still up to date")
+                }
+                _ => eprintln!("Nothing new to deploy"),
+            }
             res.push(last);
         }
         _ => {
